==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/marketplace/messages/ar/base.php <==
<?php

return [
    '<strong>Activate</strong> your Professional Edition' => '<strong> تنشيط </ strong> الإصدار المحترف الخاص بك',
    'Add purchased module by licence key' => 'إضافة وحدة مشتراة بواسطة مفتاح الترخيص',
    'All {moduleId} module content will be deleted. Continue?' => 'سيتم حذف كل محتوى الوحدة {moduleId}. استمر؟',
    'Buy (%price%)' => 'Buy (%price%)',
    'Could not connect to licence server!' => 'تعذر الاتصال بخادم الترخيص!',
    'Could not extract module!' => 'لم أتمكن من استخراج الموديول',
    'Could not remove old module path!' => 'تعذرت إزالة مسار الوحدة القديمة!',
    'Could not update licence. Error: ' => 'تعذر تحديث الترخيص. خطأ:',
    'Download of module failed!' => 'حصل خطأ أثناء تحميل الموديول',
    'Edit licence' => 'تحرير الترخيص',
    'Install' => 'تثبيت',
    'Installed' => 'تم التنصيب',
    'Installing module...' => 'جاري تثبيت الوحدة ...',
    'Latest version:' => 'احدث اصدار:',
    'Licence Key:' => 'مفتاح الترخيص:',
    'Licence key' => 'مفتاح الترخيص',
    'Licenced for max. {number} users.' => 'مرخص بحد أقصى عدد {number} مستخدم.',
    'Licenced to:' => 'مرخص لـ:',
    'Marketplace' => 'المتجر',
    'Max. users:' => 'ماكس. المستخدمون:',
    'Module directory %modulePath% is not writeable!' => 'المجلد الذي يحتوي على الموديول غير قابل للكتابة %modulePath%',
    'Module download failed! (%error%)' => 'فشل تحميل الموديول! (%error%)',
    'More info' => 'معلومات',
    'No compatible module version found!' => 'لا توجد نسخة مناسبة للموديول!',
    'No license key? Find out more about the {pro} or contact us.' => 'لا يوجد مفتاح ترخيص؟ تعرف على المزيد حول {pro} أو اتصل بنا.',
    'No purchased modules found!' => 'لم يتم العثور على وحدات مشتراة!',
    'Ok' => 'تمام',
    'Professional Edition is activated!' => 'تم تنشيط الإصدار المحترف!',
    'Register' => 'تسجيل',
    'Remove licence key' => 'إزالة مفتاح الترخيص',
    'Save and update' => 'حفظ وتحديث',
    'Third-party' => 'Third-party',
    'Third-party disclaimer' => 'Third-party disclaimer',
    'Update' => 'تحديث',
    'Upgrade to Professional Edition' => 'الترقية إلى الإصدار المحترف',
    'Version:' => 'نسخة: ',
    '
Module successfully disabled!
' => '',
    '
Module successfully enabled!
' => '',
    '
No active Professional Edition license found!
' => '',
    '
PROFESSIONAL EDITION
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '--- Disable module: {moduleId} ---

' => '',
    '--- Enable module: {moduleId} ---

' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Add Licence Key' => '',
    'All' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!
' => '',
    'Featured' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'Module not found or activated!
' => '',
    'Module not found!
' => '',
    'New' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Stop updating' => '',
    'Tags' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'This Module was developed by a third-party.' => '',
    'Update all' => '',
    'Your HumHub installation is up to date!' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/ar/base.php <==
<?php

return [
    '<strong>Activate</strong> your Professional Edition' => '<strong> تنشيط </ strong> الإصدار المحترف الخاص بك',
    'Activated' => 'تم التفعيل',
    'Add purchased module by licence key' => 'إضافة وحدة مشتراة بواسطة مفتاح الترخيص',
    'All' => 'الكل',
    'All {moduleId} module content will be deleted. Continue?' => 'سيتم حذف كل محتوى الوحدة {moduleId}. استمر؟',
    'Buy (%price%)' => 'Buy (%price%)',
    'Configure' => 'إعدادات',
    'Could not connect to licence server!' => 'تعذر الاتصال بخادم الترخيص!',
    'Could not extract module!' => 'لم أتمكن من استخراج الموديول',
    'Could not find requested module!' => 'لم يتم ايجاد الموديول المطلوب!',
    'Could not remove old module path!' => 'تعذرت إزالة مسار الوحدة القديمة!',
    'Could not update licence. Error: ' => 'تعذر تحديث الترخيص. خطأ:',
    'Download of module failed!' => 'حصل خطأ أثناء تحميل الموديول',
    'Edit licence' => 'تحرير الترخيص',
    'General Settings' => 'الاعدادات العامة',
    'Information' => 'معلومات',
    'Install' => 'تثبيت',
    'Installed' => 'تم التنصيب',
    'Latest version:' => 'احدث اصدار:',
    'Licence Key:' => 'مفتاح الترخيص:',
    'Licence key' => 'مفتاح الترخيص',
    'Licenced for max. {number} users.' => 'مرخص بحد أقصى عدد {number} مستخدم.',
    'Licenced to:' => 'مرخص لـ:',
    'Marketplace' => 'المتجر',
    'Max. users:' => 'ماكس. المستخدمون:',
    'Module directory %modulePath% is not writeable!' => 'المجلد الذي يحتوي على الموديول غير قابل للكتابة %modulePath%',
    'Module download failed! (%error%)' => 'فشل تحميل الموديول! (%error%)',
    'More info' => 'معلومات',
    'New' => 'جديد',
    'No compatible module version found!' => 'لا توجد نسخة مناسبة للموديول!',
    'No license key? Find out more about the {pro} or contact us.' => 'لا يوجد مفتاح ترخيص؟ تعرف على المزيد حول {pro} أو اتصل بنا.',
    'No modules installed yet. Install some to enhance the functionality!' => 'لا توجد موديولات بعد, قم بتحميل البعض لإضافة وظائف جديدة للموقع!',
    'No purchased modules found!' => 'لم يتم العثور على وحدات مشتراة!',
    'Ok' => 'تمام',
    'Professional Edition is activated!' => 'تم تنشيط الإصدار المحترف!',
    'Register' => 'تسجيل',
    'Remove licence key' => 'إزالة مفتاح الترخيص',
    'Save and update' => 'حفظ وتحديث',
    'Search' => 'بحث',
    'Settings' => 'إعدادات',
    'Tags' => 'الأوسمة',
    'Third-party' => 'Third-party',
    'Third-party disclaimer' => 'Third-party disclaimer',
    'Update' => 'تحديث',
    'Upgrade to Professional Edition' => 'الترقية إلى الإصدار المحترف',
    'Version:' => 'نسخة: ',
    '
Module successfully disabled!
' => '',
    '
Module successfully enabled!
' => '',
    '
No active Professional Edition license found!
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '--- Disable module: {moduleId} ---

' => '',
    '--- Enable module: {moduleId} ---

' => '',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate' => '',
    'Activate now' => '',
    'Add Licence Key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not find the requested module!' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Learn more' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace is disabled.' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'Module not found or activated!
' => '',
    'Module not found!
' => '',
    'No modules found.' => '',
    'Official' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Search...' => '',
    'Stop updating' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'This Module was developed by a third-party.' => '',
    'Try other keywords or remove filters.' => '',
    'Uninstalled' => '',
    'Update all' => '',
    'Update successful' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
    'Your HumHub installation is up to date!' => '',
];
